==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/hu.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Fényképek",
    "Your memories under your control" : "Az Ön emlékei, az Ön felügyelete alatt",
    "All media" : "Összes média",
    "Videos" : "Videók",
    "Albums" : "Albumok",
    "People" : "Emberek",
    "Folders" : "Mappák",
    "Favorites" : "Kedvencek",
    "On this day" : "A mai napon",
    "Shared with you" : "Megosztva Önnel",
    "Tags" : "Címkék",
    "Locations" : "Helyek",
    "Photos settings" : "Fényképek beállításai",
    "Mark selection as favorite" : "Kiválasztás megjelölése kedvencként",
    "Remove selection from favorites" : "Kiválasztás eltávolítása a kedvencek közül",
    "Name of the album" : "Az album neve",
    "Location of the album" : "Az album helye",
    "Go back to the previous view." : "Ugrás vissza az előző nézethez.",
    "Back" : "Vissza",
    "Go to the add collaborators view." : "Ugrás a közreműködők hozzáadása nézethez",
    "Add collaborators" : "Közreműködők hozzáadása",
    "Save." : "Mentés.",
    "Create the album." : "Album létrehozása.",
    "Save" : "Mentés",
    "Create album" : "Album létrehozása",
    "Back to the new album form." : "Vissza az új album űrlaphoz.",
    "Add to Album" : "Hozzáadás az albumhoz",
    "Create a new album." : "Új album létrehozása.",
    "Create new album" : "Új album létrehozása",
    "New album" : "Új album",
    "_%n item_::_%n photos and videos_" : ["%n fénykép és videó","%n fénykép és videó"],
    "_Share with %n user_::_Share with %n users_" : ["Megosztás %n felhasználóval","Megosztás %n felhasználóval"],
    "Copy public link" : "Nyilvános hivatkozás másolása",
    "An error occurred" : "Hiba történt",
    "_%n photos_::_%n photos_" : ["%n fénykép","%n fénykép"],
    "Select image {imageName}" : "{imageName} kép kiválasztása",
    "The file is in the favorites" : "A fájl a kedvencek között van",
    "Open the full size \"{name}\" image" : "A teljes méretű „{name}” fénykép megnyitása",
    "Add to {destination}" : "Hozzáadás ehhez: {destination}",
    "Open the \"{name}\" sub-directory" : "A(z) „name” alkönyvtár megnyitása",
    "Back to {folder}" : "Vissza ide: {folder}",
    "Share this folder" : "Mappa megosztása",
    "_{years} year ago_::_{years} years ago_" : ["{years} éve","{years} éve"],
    "Enable squared photos view" : "A négyzet alakú fotónézet engedélyezése",
    "Default Photos upload and Albums location" : "Fényképfeltöltés és Albumok alapértelmezett helye",
    "Select the default location for your media" : "Válassza ki a médiafájlok alapértelmezett helyét",
    "Invalid location selected" : "Érvénytelen hely választva",
    "View" : "Megtekintés",
    "Photos directory" : "Fényképek könyvtár",
    "_%n photo_::_%n photos_" : ["%n fénykép","%n fénykép"],
    "Edit album details" : "Album részleteinek szerkesztése",
    "Download all files in album" : "Összes fájl letöltése az albumből",
    "Delete album" : "Album törlése",
    "Download selected files" : "Kiválasztott fájlok letöltése",
    "Remove selection from album" : "Kiválasztás eltávolítása az albumból",
    "Add photos to this album" : "Fényképek hozzáadása az albumhoz",
    "Add photos to the album" : "Fényképek hozzáadása az albumhoz",
    "This person could not be found" : "Ez a személy nem található",
    "Rename person" : "Személy átnevezése",
    "Merge with different person" : "Összevonás egy másik személlyel",
    "Download selected photos" : "Kiválasztott fényképek letöltése",
    "Favorite" : "Kedvenc",
    "Remove from favorites" : "Eltávolítás a kedvencek közül",
    "Remove person" : "Személy eltávolítása",
    "Name of this person" : "A személy neve",
    "Merge person" : "Személy egyesítése",
    "_Remove photo from person_::_Remove photos from person_" : ["Fénykép eltávolítása a személytől","Fényképek eltávolítása a személytől"],
    "This might take some time depending on the size of your photo library." : "Ez a fényképkönyvtár méretétől függően eltarthat egy darabig.",
    "Recognized people will show up here" : "A felismert emberek itt fognak megjelenni",
    "This folder does not exist" : "Ez a mappa nem létezik",
    "Loading folders …" : "Mappák betöltése…",
    "No photos in here" : "Itt nincsenek fényképek",
    "Shared albums" : "Megosztott albumok",
    "Back to tags overview" : "Vissza a címkeáttekintőhöz",
    "No photos with this tag yet" : "Még nincsenek fényképek ezzel a címkével",
    "No tags yet" : "Még nincsenek címkék",
    "Photos with tags will show up here" : "A címkével rendelkező fényképek itt fognak megjelenni",
    "Popular tags" : "Népszerű címkék",
    "Add" : "Hozzáadás",
    "Create a new album" : "Új album létrehozása",
    "Add selection to an album" : "Kiválasztás hozzáadása egy albumhoz",
    "Add to album" : "Hozzáadás az albumhoz",
    "Delete selection" : "Kiválasztás törlése",
    "Failed to fetch faces list." : "Az arcok lekérése sikertelen.",
    "Tagged photos" : "Címkézett fényképek",
    "Failed to create {albumName}." : "A(z) {albumName} létrehozása sikertelen.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "A(z) {currentAlbumName} átnevezése a következőre sikertelen: {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "A(z) {oldName} átnevezése a következőre sikertelen: {faceName}.",
    "Failed to delete {faceName}." : "A(z) {faceName} törlése sikertelen.",
    "Failed to delete {fileName}." : "{fileName} törlése sikertelen.",
    "Your photos" : "Saját fényképek",
    "Your videos" : "Saját videók",
    "Your folders" : "Saját mappák",
    "Settings" : "Beállítások"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/hu.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Nyilvános hivatkozás",
    "Photos" : "Fényképek",
    "Your memories under your control" : "Az Ön emlékei, az Ön felügyelete alatt",
    "All media" : "Összes média",
    "Videos" : "Videók",
    "Albums" : "Albumok",
    "Collaborative albums" : "Közreműködőkkel készült albumok",
    "People" : "Emberek",
    "Folders" : "Mappák",
    "Favorites" : "Kedvencek",
    "On this day" : "A mai napon",
    "Shared with you" : "Megosztva Önnel",
    "Tags" : "Címkék",
    "Locations" : "Helyek",
    "Photos settings" : "Fényképek beállításai",
    "Mark selection as favorite" : "Kiválasztás megjelölése kedvencként",
    "Add selection to favorites" : "Kiválasztás hozzáadása a kedvencekhez",
    "Remove selection from favorites" : "Kiválasztás eltávolítása a kedvencek közül",
    "Name of the album" : "Az album neve",
    "Location of the album" : "Az album helye",
    "Go back to the previous view." : "Ugrás vissza az előző nézethez.",
    "Back" : "Vissza",
    "Go to the add collaborators view." : "Ugrás a közreműködők hozzáadása nézethez",
    "Add collaborators" : "Közreműködők hozzáadása",
    "Save." : "Mentés.",
    "Create the album." : "Album létrehozása.",
    "Save" : "Mentés",
    "Create album" : "Album létrehozása",
    "Back to the new album form." : "Vissza az új album űrlaphoz.",
    "Add to Album" : "Hozzáadás az albumhoz",
    "Add selection to album {albumName}" : "Kiválasztás hozzáadása a(z) {albumName} albumhoz",
    "Create a new album." : "Új album létrehozása.",
    "Create new album" : "Új album létrehozása",
    "New album" : "Új album",
    "_%n item_::_%n photos and videos_" : ["%n fénykép és videó","%n fénykép és videó"],
    "_Share with %n user_::_Share with %n users_" : ["Megosztás %n felhasználóval","Megosztás %n felhasználóval"],
    "Add people or groups who can edit your album" : "Emberek vagy csoportok hozzáadása, akik szerkeszthetik az albumot",
    "Search for collaborators" : "Közreműködők keresése",
    "Search people or groups" : "Felhasználó vagy csoport keresése",
    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} hozzáadása a közreműködőkhöz",
    "No collaborators available" : "Nem érhető el közreműködő",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} eltávolítása a közreműködőktől",
    "Copy the public link" : "Nyilvános hivatkozás másolása",
    "Public link copied!" : "Nyilvános hivatkozás másolva.",
    "Copy public link" : "Nyilvános hivatkozás másolása",
    "Delete the public link" : "Nyilvános hivatkozás törlése",
    "Share via public link" : "Megosztva nyilvános hivatkozással",
    "Failed to fetch collaborators list." : "A közreműködők lekérése sikertelen.",
    "Failed to fetch album." : "Az album lekérése sikertelen.",
    "Failed to update album." : "Az album frissítése sikertelen.",
    "This collection does not exist" : "Ez a gyűjtemény nem létezik",
    "An error occurred" : "Hiba történt",
    "_%n photos_::_%n photos_" : ["%n fénykép","%n fénykép"],
    "Select image {imageName}" : "{imageName} kép kiválasztása",
    "The file is in the favorites" : "A fájl a kedvencek között van",
    "Open the full size \"{name}\" image" : "A teljes méretű „{name}” fénykép megnyitása",
    "There are no photos or videos yet!" : "Még nincs fénykép vagy videó.",
    "Add to {destination}" : "Hozzáadás ehhez: {destination}",
    "Open the \"{name}\" sub-directory" : "A(z) „name” alkönyvtár megnyitása",
    "Back to {folder}" : "Vissza ide: {folder}",
    "Share this folder" : "Mappa megosztása",
    "_{years} year ago_::_{years} years ago_" : ["{years} éve","{years} éve"],
    "Enable squared photos view" : "A négyzet alakú fotónézet engedélyezése",
    "Default Photos upload and Albums location" : "Fényképfeltöltés és Albumok alapértelmezett helye",
    "Select the default location for your media" : "Válassza ki a médiafájlok alapértelmezett helyét",
    "Invalid location selected" : "Érvénytelen hely választva",
    "View" : "Megtekintés",
    "Photos directory" : "Fényképek könyvtár",
    "_%n photo_::_%n photos_" : ["%n fénykép","%n fénykép"],
    "Manage collaborators for this album" : "Az album közreműködőinek kezelése",
    "Open actions menu" : "Műveletek menü megnyitása",
    "Edit album details" : "Album részleteinek szerkesztése",
    "Download all files in album" : "Összes fájl letöltése az albumből",
    "Delete album" : "Album törlése",
    "Download selected files" : "Kiválasztott fájlok letöltése",
    "Remove selection from album" : "Kiválasztás eltávolítása az albumból",
    "This album does not have any photos or videos yet!" : "Még nincs fénykép vagy videó ebben az albumban.",
    "Add photos to this album" : "Fényképek hozzáadása az albumhoz",
    "Add photos to the album" : "Fényképek hozzáadása az albumhoz",
    "Manage collaborators" : "Közreműködők kezelése",
    "Save collaborators for this album." : "Közreműködők mentése ehhez az albumhoz.",
    "Cover photo for album {albumName}" : "Borítókép a(z) „{albumName}” albumhoz",
    "There is no album yet!" : "Még nincs album.",
    "This person could not be found" : "Ez a személy nem található",
    "Rename person" : "Személy átnevezése",
    "Merge with different person" : "Összevonás egy másik személlyel",
    "Download selected photos" : "Kiválasztott fényképek letöltése",
    "Favorite" : "Kedvenc",
    "Remove from favorites" : "Eltávolítás a kedvencek közül",
    "Remove person" : "Személy eltávolítása",
    "Name of this person" : "A személy neve",
    "Merge person" : "Személy egyesítése",
    "_Remove photo from person_::_Remove photos from person_" : ["Fénykép eltávolítása a személytől","Fényképek eltávolítása a személytől"],
    "This might take some time depending on the size of your photo library." : "Ez a fényképkönyvtár méretétől függően eltarthat egy darabig.",
    "Recognized people will show up here" : "A felismert emberek itt fognak megjelenni",
    "This folder does not exist" : "Ez a mappa nem létezik",
    "Loading folders …" : "Mappák betöltése…",
    "No photos in here" : "Itt nincsenek fényképek",
    "Failed to fetch albums list." : "Az albumok lekérése sikertelen.",
    "Shared albums" : "Megosztott albumok",
    "Cover photo for shared album {albumName}." : "Borítókép a(z) „{albumName}” megosztott albumhoz.",
    "Back to tags overview" : "Vissza a címkeáttekintőhöz",
    "No photos with this tag yet" : "Még nincsenek fényképek ezzel a címkével",
    "No tags yet" : "Még nincsenek címkék",
    "Photos with tags will show up here" : "A címkével rendelkező fényképek itt fognak megjelenni",
    "Popular tags" : "Népszerű címkék",
    "Add" : "Hozzáadás",
    "Create a new album" : "Új album létrehozása",
    "Add selection to an album" : "Kiválasztás hozzáadása egy albumhoz",
    "Add to album" : "Hozzáadás az albumhoz",
    "Delete selection" : "Kiválasztás törlése",
    "No photos or videos in here" : "Itt nincs fénykép vagy videó",
    "Failed to fetch faces list." : "Az arcok lekérése sikertelen.",
    "All your media" : "Összes saját média",
    "Album {title}" : "Album: {title}",
    "Shared Albums" : "Megosztott albumok",
    "Shared album {title}" : "Megosztott album: {title}",
    "Public album {title}" : "Nyilvános album: {title}",
    "Tagged photos" : "Címkézett fényképek",
    "Tagged photo {title}" : "Címkézett fénykép: {title}",
    "{title}'s face" : "{title} arca",
    "Failed to create {albumName}." : "A(z) {albumName} létrehozása sikertelen.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "A(z) {currentAlbumName} átnevezése a következőre sikertelen: {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "A(z) {oldName} átnevezése a következőre sikertelen: {faceName}.",
    "Failed to delete {faceName}." : "A(z) {faceName} törlése sikertelen.",
    "Failed to delete {fileId}." : "A(z) {fileId} törlése sikertelen.",
    "Failed to delete {fileName}." : "A(z) {fileName} törlése sikertelen.",
    "Failed to set favorite state for {fileId}." : "A(z) {fileId} kedvenc állapotának beállítása sikertelen.",
    "Failed to set favorite state for {fileName}." : "A(z) {fileName} kedvenc állapotának beállítása sikertelen.",
    "Your photos" : "Saját fényképek",
    "Your videos" : "Saját videók",
    "Your folders" : "Saját mappák",
    "Settings" : "Beállítások"
},
"nplurals=2; plural=(n != 1);");
